export ZSH="$HOME/.oh-my-zsh"

# Appearence
ZSH_THEME="agnoster"
plugins=(git colored-man-pages colorize pip python poetry brew zsh-autosuggestions)

# Updates
zstyle ':omz:update' mode auto      # update automatically without asking
zstyle ':omz:update' frequency 13

# Domain
{{ domain_export }}

# API Keys
{{ config }}

# Source
source $ZSH/oh-my-zsh.sh