<!DOCTYPE html>
<html lang="en">

{% include 'head.html' %}

<body>

<header>
  {% if data %}

  <p>{{ data['msg'] }} from <span>pd</span></p>

  {% else %}

  <p>Welcome to <span>pd</span></p>

  {% endif %}
</header>

{% include 'logo.html' %}

<footer>
  <p>Generated by pd © 2023. All Rights Reserved.</p>
</footer>

</body>
</html>