<head>
  <meta charset="utf-8"/>
  <link rel="icon" href="/static/favicon.ico"/>
  <meta name="viewport" content="width=device-width, initial-scale=1"/>
  <meta name="theme-color" content="#000000"/>

  <meta name="description" content="FastAPI App generated by pd">
  <meta name="author" content="pd">

  <link rel="apple-touch-icon" href="/static/logo192.png"/>

  <link rel="manifest" href="/static/manifest.json"/>

  <link rel="stylesheet" href="/static/css/index.css">
  <script src="/static/js/index.js"></script>

  <title>FastAPI App</title>
</head>